Module hashmap

Module hashmap 

Merge strategies for hash maps.

These strategies are only available if the std feature is enabled.

Functions

append_or_ignore
Append values, on conflict, ignore elements from right.
append_or_overwrite
Append values, on conflict, overwrite elements of left with right.
append_or_recurse
Append values, on conflict, recursively merge the elements.